@@ -1,8 +1,12 @@
+""" Standard Chess game"""
+
 from pychess.Utils.Board import Board
 
+
 class NormalBoard(Board):
-    __desc__ = _("Classic chess rules\n" +
-                 "http://en.wikipedia.org/wiki/Chess")
+    """:Description: A standard chess game board setup"""
+
+    __desc__ = _("Classic chess rules\n" + "http://en.wikipedia.org/wiki/Chess")
     name = _("Normal")
     cecp_name = "normal"
     need_initial_board = False
