@@ -1,22 +1,50 @@
-# -*- coding: utf-8 -*-
 import asyncio
 import datetime
 from gi.repository import GLib, GObject
 
-from pychess.compat import create_task
 from pychess.System.Log import log
 from pychess.Utils.IconLoader import load_icon, get_pixbuf
 from pychess.Utils.const import ADJOURNED, WHITE, BLACK, UNSUPPORTED
 
-from pychess.ic import RATING_TYPES, IC_STATUS_PLAYING, IC_STATUS_OFFLINE, IC_STATUS_UNKNOWN, \
-    IC_STATUS_AVAILABLE, IC_STATUS_IDLE, IC_STATUS_EXAMINING, IC_STATUS_NOT_AVAILABLE, \
-    IC_STATUS_BUSY, IC_STATUS_RUNNING_SIMUL_MATCH, IC_STATUS_IN_TOURNAMENT, \
-    TITLE_TYPE_DISPLAY_TEXTS, TITLE_TYPE_DISPLAY_TEXTS_SHORT, TYPE_BLITZ, TYPE_STANDARD, \
-    TYPE_ATOMIC, TYPE_LIGHTNING, TYPE_BUGHOUSE, TYPE_CRAZYHOUSE, TYPE_LOSERS, TYPE_SUICIDE, \
-    TYPE_WILD, GAME_TYPES_BY_RATING_TYPE, TYPE_UNREGISTERED, TYPE_COMPUTER, TYPE_ADMINISTRATOR, \
-    DEVIATION_NONE, DEVIATION_ESTIMATED, DEVIATION_PROVISIONAL, GAME_TYPES_BY_FICS_NAME, \
-    GAME_TYPES, TYPE_GRAND_MASTER, TYPE_INTERNATIONAL_MASTER, TYPE_FIDE_MASTER, \
-    TYPE_WOMAN_GRAND_MASTER, TYPE_WOMAN_INTERNATIONAL_MASTER, TYPE_WOMAN_FIDE_MASTER
+from pychess.ic import (
+    RATING_TYPES,
+    IC_STATUS_PLAYING,
+    IC_STATUS_OFFLINE,
+    IC_STATUS_UNKNOWN,
+    IC_STATUS_AVAILABLE,
+    IC_STATUS_IDLE,
+    IC_STATUS_EXAMINING,
+    IC_STATUS_NOT_AVAILABLE,
+    IC_STATUS_BUSY,
+    IC_STATUS_RUNNING_SIMUL_MATCH,
+    IC_STATUS_IN_TOURNAMENT,
+    TITLE_TYPE_DISPLAY_TEXTS,
+    TITLE_TYPE_DISPLAY_TEXTS_SHORT,
+    TYPE_BLITZ,
+    TYPE_STANDARD,
+    TYPE_ATOMIC,
+    TYPE_LIGHTNING,
+    TYPE_BUGHOUSE,
+    TYPE_CRAZYHOUSE,
+    TYPE_LOSERS,
+    TYPE_SUICIDE,
+    TYPE_WILD,
+    GAME_TYPES_BY_RATING_TYPE,
+    TYPE_UNREGISTERED,
+    TYPE_COMPUTER,
+    TYPE_ADMINISTRATOR,
+    DEVIATION_NONE,
+    DEVIATION_ESTIMATED,
+    DEVIATION_PROVISIONAL,
+    GAME_TYPES_BY_FICS_NAME,
+    GAME_TYPES,
+    TYPE_GRAND_MASTER,
+    TYPE_INTERNATIONAL_MASTER,
+    TYPE_FIDE_MASTER,
+    TYPE_WOMAN_GRAND_MASTER,
+    TYPE_WOMAN_INTERNATIONAL_MASTER,
+    TYPE_WOMAN_FIDE_MASTER,
+)
 
 
 class AlreadyExistException(Exception):
@@ -29,8 +57,11 @@ def make_sensitive_if_available(button, player):
         button.set_property("tooltip-text", "")
     else:
         button.set_property("sensitive", False)
-        button.set_property("tooltip-text", _("%(player)s is %(status)s") %
-                            {"player": player.name, "status": player.display_status.lower()})
+        button.set_property(
+            "tooltip-text",
+            _("%(player)s is %(status)s")
+            % {"player": player.name, "status": player.display_status.lower()},
+        )
 
 
 def make_sensitive_if_playing(button, player):
@@ -41,52 +72,53 @@ def make_sensitive_if_playing(button, player):
         button.set_property("sensitive", False)
         if player.status != IC_STATUS_OFFLINE:
             status = _("not playing")
-    button.set_property("tooltip-text", _("%(player)s is %(status)s") %
-                        {"player": player.name, "status": status})
+    button.set_property(
+        "tooltip-text",
+        _("%(player)s is %(status)s") % {"player": player.name, "status": status},
+    )
 
 
 def get_player_tooltip_text(player, show_status=True):
     text = "%s" % player.name
     text += "%s" % player.display_titles(long=True)
     if player.blitz:
-        text += "\n%s: %s" % (_("Blitz"), player.blitz)
+        text += "\n{}: {}".format(_("Blitz"), player.blitz)
     if player.standard:
-        text += "\n%s: %s" % (_("Standard"), player.standard)
+        text += "\n{}: {}".format(_("Standard"), player.standard)
     if player.lightning:
-        text += "\n%s: %s" % (_("Lightning"), player.lightning)
+        text += "\n{}: {}".format(_("Lightning"), player.lightning)
     if player.atomic:
-        text += "\n%s: %s" % (_("Atomic"), player.atomic)
+        text += "\n{}: {}".format(_("Atomic"), player.atomic)
     if player.bughouse:
-        text += "\n%s: %s" % (_("Bughouse"), player.bughouse)
+        text += "\n{}: {}".format(_("Bughouse"), player.bughouse)
     if player.crazyhouse:
-        text += "\n%s: %s" % (_("Crazyhouse"), player.crazyhouse)
+        text += "\n{}: {}".format(_("Crazyhouse"), player.crazyhouse)
     if player.losers:
-        text += "\n%s: %s" % (_("Losers"), player.losers)
+        text += "\n{}: {}".format(_("Losers"), player.losers)
     if player.suicide:
-        text += "\n%s: %s" % (_("Suicide"), player.suicide)
+        text += "\n{}: {}".format(_("Suicide"), player.suicide)
     if player.wild:
-        text += "\n%s: %s" % (_("Wild"), player.wild)
+        text += "\n{}: {}".format(_("Wild"), player.wild)
     if show_status:
         text += "\n%s" % player.display_status
     return text
 
 
 def player_id(name):
-    """ Two players are equal if the first 11 characters of their name match.
-        This is to facilitate matching players from output of commands like the 'games'
-        command which only return the first 11 characters of a player's name """
+    """Two players are equal if the first 11 characters of their name match.
+    This is to facilitate matching players from output of commands like the 'games'
+    command which only return the first 11 characters of a player's name"""
     return name[0:11].lower()
 
 
 class FICSPlayer(GObject.GObject):
-    __gsignals__ = {'ratings_changed': (GObject.SignalFlags.RUN_FIRST, None, (int, object))}
+    __gsignals__ = {
+        "ratings_changed": (GObject.SignalFlags.RUN_FIRST, None, (int, object))
+    }
 
-    def __init__(self,
-                 name,
-                 online=False,
-                 status=IC_STATUS_UNKNOWN,
-                 game=None,
-                 titles=None):
+    def __init__(
+        self, name, online=False, status=IC_STATUS_UNKNOWN, game=None, titles=None
+    ):
         assert isinstance(name, str), name
         assert isinstance(online, bool), online
         GObject.GObject.__init__(self)
@@ -140,6 +172,7 @@ class FICSPlayer(GObject.GObject):
     def set_status(self, status):
         self._previous_status = self._status
         self._status = status
+
     status = GObject.property(get_status, set_status)
 
     def restore_previous_status(self):
@@ -257,24 +290,33 @@ class FICSPlayer(GObject.GObject):
             rep += ", game=None"
         for rating_type in RATING_TYPES:
             if rating_type in self.ratings:
-                rep += ", %s=%s" % \
-                    (GAME_TYPES_BY_RATING_TYPE[rating_type].display_text,
-                     repr(self.ratings[rating_type]))
+                rep += ", {}={}".format(
+                    GAME_TYPES_BY_RATING_TYPE[rating_type].display_text,
+                    repr(self.ratings[rating_type]),
+                )
         return "<FICSPlayer " + rep + ">"
 
     def isAvailableForGame(self):
-        if self.status in \
-            (IC_STATUS_PLAYING, IC_STATUS_BUSY, IC_STATUS_OFFLINE,
-             IC_STATUS_RUNNING_SIMUL_MATCH, IC_STATUS_NOT_AVAILABLE,
-             IC_STATUS_EXAMINING, IC_STATUS_IN_TOURNAMENT):
+        if self.status in (
+            IC_STATUS_PLAYING,
+            IC_STATUS_BUSY,
+            IC_STATUS_OFFLINE,
+            IC_STATUS_RUNNING_SIMUL_MATCH,
+            IC_STATUS_NOT_AVAILABLE,
+            IC_STATUS_EXAMINING,
+            IC_STATUS_IN_TOURNAMENT,
+        ):
             return False
         else:
             return True
 
     def isObservable(self):
-        return self.status == IC_STATUS_EXAMINING or \
-            (self.status == IC_STATUS_PLAYING and
-             self.game is not None and not self.game.private and self.game.supported)
+        return self.status == IC_STATUS_EXAMINING or (
+            self.status == IC_STATUS_PLAYING
+            and self.game is not None
+            and not self.game.private
+            and self.game.supported
+        )
 
     def isGuest(self):
         return TYPE_UNREGISTERED in self.titles
@@ -287,12 +329,13 @@ class FICSPlayer(GObject.GObject):
 
     def isTitled(self):
         return (
-            TYPE_GRAND_MASTER in self.titles) or (
-            TYPE_INTERNATIONAL_MASTER in self.titles) or (
-            TYPE_FIDE_MASTER in self.titles) or (
-            TYPE_WOMAN_GRAND_MASTER in self.titles) or (
-            TYPE_WOMAN_INTERNATIONAL_MASTER in self.titles) or (
-            TYPE_WOMAN_FIDE_MASTER in self.titles)
+            (TYPE_GRAND_MASTER in self.titles)
+            or (TYPE_INTERNATIONAL_MASTER in self.titles)
+            or (TYPE_FIDE_MASTER in self.titles)
+            or (TYPE_WOMAN_GRAND_MASTER in self.titles)
+            or (TYPE_WOMAN_INTERNATIONAL_MASTER in self.titles)
+            or (TYPE_WOMAN_FIDE_MASTER in self.titles)
+        )
 
     @classmethod
     def getIconByRating(cls, rating, size=16):
@@ -393,8 +436,8 @@ class FICSPlayer(GObject.GObject):
 
 class FICSPlayers(GObject.GObject):
     __gsignals__ = {
-        'FICSPlayerEntered': (GObject.SignalFlags.RUN_FIRST, None, (object, )),
-        'FICSPlayerExited': (GObject.SignalFlags.RUN_FIRST, None, (object, ))
+        "FICSPlayerEntered": (GObject.SignalFlags.RUN_FIRST, None, (object,)),
+        "FICSPlayerExited": (GObject.SignalFlags.RUN_FIRST, None, (object,)),
     }
 
     def __init__(self, connection):
@@ -416,7 +459,7 @@ class FICSPlayers(GObject.GObject):
             raise KeyError
 
     def __setitem__(self, key, value):
-        """ key must be str and value must be FICSPlayer object """
+        """key must be str and value must be FICSPlayer object"""
         if not isinstance(key, str):
             raise TypeError
         if not isinstance(value, FICSPlayer):
@@ -426,7 +469,8 @@ class FICSPlayers(GObject.GObject):
 
         self.players[value.player_id] = value
         self.players_cids[value.player_id] = value.connect(
-            "notify::online", self.online_changed)
+            "notify::online", self.online_changed
+        )
 
     def __delitem__(self, name):
         if not isinstance(name, str):
@@ -458,10 +502,14 @@ class FICSPlayers(GObject.GObject):
 
     def online_changed(self, player, prop):
         if player.online:
-            GLib.idle_add(self.emit,
-                          "FICSPlayerEntered",
-                          [player, ],
-                          priority=GLib.PRIORITY_LOW)
+            GLib.idle_add(
+                self.emit,
+                "FICSPlayerEntered",
+                [
+                    player,
+                ],
+                priority=GLib.PRIORITY_LOW,
+            )
 
     # This method is a temporary hack until ChatWindow/ChatManager are
     # converted to use FICSPlayer references rather than player's names
@@ -493,20 +541,25 @@ class FICSPlayers(GObject.GObject):
             player = self[key]
             player.online = False
             player.status = IC_STATUS_OFFLINE
-            if not player.adjournment and player.name not in self.connection.notify_users:
+            if (
+                not player.adjournment
+                and player.name not in self.connection.notify_users
+            ):
                 del self[player.player_id]
             else:
-                log.debug("Not removing %s" % player,
-                          extra={"task": (self.connection.username,
-                                          "player_disconnected")})
-            GLib.idle_add(self.emit,
-                          'FICSPlayerExited',
-                          player,
-                          priority=GLib.PRIORITY_LOW)
+                log.debug(
+                    "Not removing %s" % player,
+                    extra={"task": (self.connection.username, "player_disconnected")},
+                )
+            GLib.idle_add(
+                self.emit, "FICSPlayerExited", player, priority=GLib.PRIORITY_LOW
+            )
         else:
-            log.debug("Not removing %s (it's not in FICSPlayers)" % name,
-                      extra={"task": (self.connection.username,
-                                      "player_disconnected")})
+            log.debug(
+                "Not removing %s (it's not in FICSPlayers)" % name,
+                extra={"task": (self.connection.username, "player_disconnected")},
+            )
+
     #    def onFinger (self, fm, finger):
     #        player = player_id(finger.getName())
     #        if player in self:
@@ -519,8 +572,11 @@ class FICSMatch(GObject.GObject):
         assert minutes is None or isinstance(minutes, int), type(minutes)
         assert inc is None or isinstance(inc, int), inc
         assert isinstance(rated, bool), rated
-        assert game_type is None or game_type is GAME_TYPES_BY_FICS_NAME["wild"] \
-            or game_type in GAME_TYPES.values(), game_type
+        assert (
+            game_type is None
+            or game_type is GAME_TYPES_BY_FICS_NAME["wild"]
+            or game_type in GAME_TYPES.values()
+        ), game_type
         GObject.GObject.__init__(self)
         self.minutes = minutes
         self.inc = inc
@@ -528,7 +584,7 @@ class FICSMatch(GObject.GObject):
         self.game_type = game_type
 
     def __repr__(self):
-        text = "%s %s" % (self.minutes, self.inc)
+        text = f"{self.minutes} {self.inc}"
         text += " %s" % ("rated" if self.rated else "unrated")
         text += " %s" % self.game_type.display_text
         return text
@@ -552,7 +608,7 @@ class FICSMatch(GObject.GObject):
     @property
     def sortable_time(self):
         # http://www.freechess.org/Help/HelpFiles/etime.html
-        etime = self.minutes + int(round(self.inc * 2. / 3.))
+        etime = self.minutes + int(round(self.inc * 2.0 / 3.0))
         return etime
 
 
@@ -561,12 +617,13 @@ def get_soughtmatch_tooltip_text(sought):
     text += "%s" % sought.player.display_titles(long=True)
     if not sought.player.isGuest():
         text += " (%d)" % sought.player_rating
-    text += "\n%s %s" % (sought.display_rated, sought.game_type.display_text)
+    text += f"\n{sought.display_rated} {sought.game_type.display_text}"
     text += "\n" + sought.display_timecontrol
     if sought.color:
-        text += "\n" + _("%(player)s plays %(color)s") \
-            % {"player": sought.player.name,
-               "color": _("white") if sought.color == "white" else _("black")}
+        text += "\n" + _("%(player)s plays %(color)s") % {
+            "player": sought.player.name,
+            "color": _("white") if sought.color == "white" else _("black"),
+        }
     return text
 
 
@@ -606,8 +663,8 @@ class FICSSoughtMatch(FICSMatch):
         standard time-control rating if they have one.
         """
         game_type = self.game_type
-        if game_type == GAME_TYPES['untimed']:
-            game_type = GAME_TYPES['standard']
+        if game_type == GAME_TYPES["untimed"]:
+            game_type = GAME_TYPES["standard"]
         return self.player.getRatingByGameType(game_type)
 
 
@@ -619,26 +676,19 @@ def get_challenge_tooltip_text(challenge):
 
 
 class FICSChallenge(FICSSoughtMatch):
-    def __init__(self,
-                 index,
-                 player,
-                 minutes,
-                 inc,
-                 rated,
-                 color,
-                 game_type,
-                 adjourned=False):
-        FICSSoughtMatch.__init__(self, index, player, minutes, inc, rated,
-                                 color, game_type)
+    def __init__(
+        self, index, player, minutes, inc, rated, color, game_type, adjourned=False
+    ):
+        FICSSoughtMatch.__init__(
+            self, index, player, minutes, inc, rated, color, game_type
+        )
         self.adjourned = adjourned
 
 
 class FICSChallenges(GObject.GObject):
     __gsignals__ = {
-        'FICSChallengeIssued': (GObject.SignalFlags.RUN_FIRST, None,
-                                (object, )),
-        'FICSChallengeRemoved': (GObject.SignalFlags.RUN_FIRST, None,
-                                 (object, ))
+        "FICSChallengeIssued": (GObject.SignalFlags.RUN_FIRST, None, (object,)),
+        "FICSChallengeRemoved": (GObject.SignalFlags.RUN_FIRST, None, (object,)),
     }
 
     def __init__(self, connection):
@@ -648,8 +698,7 @@ class FICSChallenges(GObject.GObject):
 
     def start(self):
         self.connection.om.connect("onChallengeAdd", self.onChallengeIssued)
-        self.connection.om.connect("onChallengeRemove",
-                                   self.onChallengeRemoved)
+        self.connection.om.connect("onChallengeRemove", self.onChallengeRemoved)
         self.connection.bm.connect("playGameCreated", self.onPlayingGame)
 
     def __getitem__(self, index):
@@ -663,11 +712,12 @@ class FICSChallenges(GObject.GObject):
         if not isinstance(challenge, FICSSoughtMatch):
             raise TypeError
         if index in self:
-            log.warning("FICSChallenges: not overwriting challenge %s" %
-                        repr(challenge))
+            log.warning(
+                "FICSChallenges: not overwriting challenge %s" % repr(challenge)
+            )
             return
         self.challenges[index] = challenge
-        self.emit('FICSChallengeIssued', challenge)
+        self.emit("FICSChallengeIssued", challenge)
 
     def __delitem__(self, index):
         if not isinstance(index, int):
@@ -677,7 +727,7 @@ class FICSChallenges(GObject.GObject):
         except KeyError:
             return
         del self.challenges[index]
-        self.emit('FICSChallengeRemoved', challenge)
+        self.emit("FICSChallengeRemoved", challenge)
 
     def __contains__(self, index):
         if not isinstance(index, int):
@@ -708,11 +758,11 @@ def get_rating_range_display_text(rmin=0, rmax=9999):
     if rmin > 0:
         text = "%d" % rmin
         if rmax == 9999:
-            text += u"↑"
+            text += "↑"
         else:
             text += "-%d" % rmax
     elif rmax != 9999:
-        text = u"%d↓" % rmax
+        text = "%d↓" % rmax
     else:
         text = None
     return text
@@ -722,27 +772,30 @@ def get_seek_tooltip_text(seek):
     text = get_soughtmatch_tooltip_text(seek)
     rrtext = get_rating_range_display_text(seek.rmin, seek.rmax)
     if rrtext:
-        text += "\n%s: %s" % (_("Opponent Rating"), rrtext)
+        text += "\n{}: {}".format(_("Opponent Rating"), rrtext)
     if not seek.automatic:
         text += "\n%s" % _("Manual Accept")
     return text
 
 
 class FICSSeek(FICSSoughtMatch):
-    def __init__(self,
-                 index,
-                 player,
-                 minutes,
-                 inc,
-                 rated,
-                 color,
-                 game_type,
-                 rmin=0,
-                 rmax=9999,
-                 automatic=True,
-                 formula=False):
-        FICSSoughtMatch.__init__(self, index, player, minutes, inc, rated,
-                                 color, game_type)
+    def __init__(
+        self,
+        index,
+        player,
+        minutes,
+        inc,
+        rated,
+        color,
+        game_type,
+        rmin=0,
+        rmax=9999,
+        automatic=True,
+        formula=False,
+    ):
+        FICSSoughtMatch.__init__(
+            self, index, player, minutes, inc, rated, color, game_type
+        )
         self.rmin = rmin  # minimum rating one has to accept this seek
         self.rmax = rmax  # maximum rating one has to accept this seek
         self.automatic = automatic  # if True, auto accept; otherwise, manual accept
@@ -751,8 +804,8 @@ class FICSSeek(FICSSoughtMatch):
 
 class FICSSeeks(GObject.GObject):
     __gsignals__ = {
-        'FICSSeekCreated': (GObject.SignalFlags.RUN_FIRST, None, (object, )),
-        'FICSSeekRemoved': (GObject.SignalFlags.RUN_FIRST, None, (object, ))
+        "FICSSeekCreated": (GObject.SignalFlags.RUN_FIRST, None, (object,)),
+        "FICSSeekRemoved": (GObject.SignalFlags.RUN_FIRST, None, (object,)),
     }
 
     def __init__(self, connection):
@@ -780,7 +833,7 @@ class FICSSeeks(GObject.GObject):
             log.warning("FICSSeeks: not overwriting seek %s" % repr(seek))
             return
         self.seeks[index] = seek
-        self.emit('FICSSeekCreated', seek)
+        self.emit("FICSSeekCreated", seek)
 
     def __delitem__(self, index):
         if not isinstance(index, int):
@@ -790,7 +843,7 @@ class FICSSeeks(GObject.GObject):
         except KeyError:
             return
         del self.seeks[index]
-        self.emit('FICSSeekRemoved', seek)
+        self.emit("FICSSeekRemoved", seek)
 
     def __contains__(self, index):
         if not isinstance(index, int):
@@ -818,7 +871,7 @@ class FICSSeeks(GObject.GObject):
         self.connection.glm.refresh_seeks()
 
 
-class FICSBoard(object):
+class FICSBoard:
     def __init__(self, wms, bms, fen=None, pgn=None):
         assert isinstance(wms, int), wms
         assert isinstance(bms, int), bms
@@ -829,24 +882,26 @@ class FICSBoard(object):
         self.pgn = pgn
 
     def __repr__(self):
-        rep = "wms=%s\nbms=%s\npgn=%s" % (self.wms, self.bms, self.pgn)
+        rep = f"wms={self.wms}\nbms={self.bms}\npgn={self.pgn}"
         return rep
 
 
 class FICSGame(FICSMatch):
-    def __init__(self,
-                 wplayer,
-                 bplayer,
-                 gameno=None,
-                 game_type=None,
-                 rated=False,
-                 minutes=None,
-                 inc=None,
-                 result=None,
-                 reason=None,
-                 board=None,
-                 private=False,
-                 relation=None):
+    def __init__(
+        self,
+        wplayer,
+        bplayer,
+        gameno=None,
+        game_type=None,
+        rated=False,
+        minutes=None,
+        inc=None,
+        result=None,
+        reason=None,
+        board=None,
+        private=False,
+        relation=None,
+    ):
         assert isinstance(wplayer, FICSPlayer), wplayer
         assert isinstance(bplayer, FICSPlayer), bplayer
         assert gameno is None or isinstance(gameno, int), gameno
@@ -868,8 +923,15 @@ class FICSGame(FICSMatch):
         self.move_queue = asyncio.Queue()
 
     def __hash__(self):
-        return hash(":".join((self.wplayer.name[0:11].lower(
-        ), self.bplayer.name[0:11].lower(), str(self.gameno))))
+        return hash(
+            ":".join(
+                (
+                    self.wplayer.name[0:11].lower(),
+                    self.bplayer.name[0:11].lower(),
+                    str(self.gameno),
+                )
+            )
+        )
 
     def __eq__(self, game):
         if isinstance(game, FICSGame) and hash(self) == hash(game):
@@ -878,8 +940,10 @@ class FICSGame(FICSMatch):
             return False
 
     def __repr__(self):
-        rep = "<FICSGame wplayer=%s, bplayer=%s" % \
-            (repr(self.wplayer), repr(self.bplayer))
+        rep = "<FICSGame wplayer={}, bplayer={}".format(
+            repr(self.wplayer),
+            repr(self.bplayer),
+        )
         if self.gameno is not None:
             rep += ", gameno=%d" % self.gameno
         rep += ", game_type=%s" % self.game_type
@@ -922,10 +986,14 @@ class FICSGame(FICSMatch):
             self.minutes = game.minutes
         if game.inc is not None and self.inc != game.inc:
             self.inc = game.inc
-        if game.game_type is not None and \
-                self.game_type != game.game_type and not \
-                (self.game_type is not None and
-                 game.game_type is GAME_TYPES_BY_FICS_NAME["wild"]):
+        if (
+            game.game_type is not None
+            and self.game_type != game.game_type
+            and not (
+                self.game_type is not None
+                and game.game_type is GAME_TYPES_BY_FICS_NAME["wild"]
+            )
+        ):
             self.game_type = game.game_type
         if game.result is not None and self.result != game.result:
             self.result = game.result
@@ -939,45 +1007,48 @@ class FICSGame(FICSMatch):
         if self.game_type is GAME_TYPES_BY_FICS_NAME["wild"]:
             return True
         elif self.game_type is not None and self.game_type.fics_name in GAME_TYPES:
-            return not GAME_TYPES[
-                self.game_type.fics_name].variant_type in UNSUPPORTED
+            return not GAME_TYPES[self.game_type.fics_name].variant_type in UNSUPPORTED
         else:
             return False
 
 
 class FICSAdjournedGame(FICSGame):
-    def __init__(self,
-                 wplayer,
-                 bplayer,
-                 our_color=None,
-                 length=None,
-                 time=None,
-                 rated=False,
-                 game_type=None,
-                 private=False,
-                 minutes=None,
-                 inc=None,
-                 result=ADJOURNED,
-                 reason=None,
-                 board=None,
-                 relation=None,
-                 gameno=None):
+    def __init__(
+        self,
+        wplayer,
+        bplayer,
+        our_color=None,
+        length=None,
+        time=None,
+        rated=False,
+        game_type=None,
+        private=False,
+        minutes=None,
+        inc=None,
+        result=ADJOURNED,
+        reason=None,
+        board=None,
+        relation=None,
+        gameno=None,
+    ):
         assert our_color is None or our_color in (WHITE, BLACK), our_color
         assert length is None or isinstance(length, int), length
         assert time is None or isinstance(time, datetime.datetime), time
-        FICSGame.__init__(self,
-                          wplayer,
-                          bplayer,
-                          rated=rated,
-                          private=private,
-                          game_type=game_type,
-                          minutes=minutes,
-                          inc=inc,
-                          result=result,
-                          reason=reason,
-                          board=board,
-                          relation=relation,
-                          gameno=gameno)
+        FICSGame.__init__(
+            self,
+            wplayer,
+            bplayer,
+            rated=rated,
+            private=private,
+            game_type=game_type,
+            minutes=minutes,
+            inc=inc,
+            result=result,
+            reason=reason,
+            board=board,
+            relation=relation,
+            gameno=gameno,
+        )
         self.our_color = our_color
         self.length = length
         self.time = time
@@ -998,7 +1069,7 @@ class FICSAdjournedGame(FICSGame):
     @property
     def display_time(self):
         if self.time is not None:
-            return self.time.isoformat(' ')[0:16]
+            return self.time.isoformat(" ")[0:16]
 
     @property
     def opponent(self):
@@ -1009,95 +1080,116 @@ class FICSAdjournedGame(FICSGame):
 
 
 class FICSHistoryGame(FICSGame):
-    def __init__(self,
-                 wplayer,
-                 bplayer,
-                 time=None,
-                 rated=False,
-                 game_type=None,
-                 private=False,
-                 minutes=None,
-                 inc=None,
-                 result=None,
-                 reason=None,
-                 board=None,
-                 relation=None,
-                 wrating=None,
-                 brating=None,
-                 gameno=None,
-                 history_no=None):
+    def __init__(
+        self,
+        wplayer,
+        bplayer,
+        time=None,
+        rated=False,
+        game_type=None,
+        private=False,
+        minutes=None,
+        inc=None,
+        result=None,
+        reason=None,
+        board=None,
+        relation=None,
+        wrating=None,
+        brating=None,
+        gameno=None,
+        history_no=None,
+    ):
         assert time is None or isinstance(time, datetime.datetime), time
-        FICSGame.__init__(self,
-                          wplayer,
-                          bplayer,
-                          rated=rated,
-                          private=private,
-                          game_type=game_type,
-                          minutes=minutes,
-                          inc=inc,
-                          result=result,
-                          reason=reason,
-                          board=board,
-                          relation=relation,
-                          gameno=gameno)
+        FICSGame.__init__(
+            self,
+            wplayer,
+            bplayer,
+            rated=rated,
+            private=private,
+            game_type=game_type,
+            minutes=minutes,
+            inc=inc,
+            result=result,
+            reason=reason,
+            board=board,
+            relation=relation,
+            gameno=gameno,
+        )
         self.time = time
         self.wrating = wrating
         self.brating = brating
         self.history_no = history_no
 
     def __hash__(self):
-        return hash(":".join((self.wplayer.name[0:11].lower(
-        ), self.bplayer.name[0:11].lower(), str(self.history_no), str(
-            self.time))))
+        return hash(
+            ":".join(
+                (
+                    self.wplayer.name[0:11].lower(),
+                    self.bplayer.name[0:11].lower(),
+                    str(self.history_no),
+                    str(self.time),
+                )
+            )
+        )
 
     @property
     def display_time(self):
         if self.time is not None:
-            return self.time.isoformat(' ')[0:16]
+            return self.time.isoformat(" ")[0:16]
 
 
 class FICSJournalGame(FICSGame):
-    def __init__(self,
-                 wplayer,
-                 bplayer,
-                 our_color=None,
-                 time=None,
-                 rated=False,
-                 game_type=None,
-                 private=False,
-                 minutes=None,
-                 inc=None,
-                 result=None,
-                 reason=None,
-                 board=None,
-                 relation=None,
-                 wrating=None,
-                 brating=None,
-                 gameno=None,
-                 journal_no=None):
+    def __init__(
+        self,
+        wplayer,
+        bplayer,
+        our_color=None,
+        time=None,
+        rated=False,
+        game_type=None,
+        private=False,
+        minutes=None,
+        inc=None,
+        result=None,
+        reason=None,
+        board=None,
+        relation=None,
+        wrating=None,
+        brating=None,
+        gameno=None,
+        journal_no=None,
+    ):
         assert our_color is None or our_color in (WHITE, BLACK), our_color
         assert time is None or isinstance(time, datetime.datetime), time
-        FICSGame.__init__(self,
-                          wplayer,
-                          bplayer,
-                          rated=rated,
-                          private=private,
-                          game_type=game_type,
-                          minutes=minutes,
-                          inc=inc,
-                          result=result,
-                          reason=reason,
-                          board=board,
-                          relation=relation,
-                          gameno=gameno)
+        FICSGame.__init__(
+            self,
+            wplayer,
+            bplayer,
+            rated=rated,
+            private=private,
+            game_type=game_type,
+            minutes=minutes,
+            inc=inc,
+            result=result,
+            reason=reason,
+            board=board,
+            relation=relation,
+            gameno=gameno,
+        )
         self.wrating = wrating
         self.brating = brating
         self.journal_no = journal_no
 
     def __hash__(self):
-        return hash(":".join((self.wplayer.name[0:11].lower(),
-                              self.bplayer.name[0:11].lower(),
-                              str(self.journal_no), )))
+        return hash(
+            ":".join(
+                (
+                    self.wplayer.name[0:11].lower(),
+                    self.bplayer.name[0:11].lower(),
+                    str(self.journal_no),
+                )
+            )
+        )
 
     @property
     def display_time(self):
@@ -1106,14 +1198,11 @@ class FICSJournalGame(FICSGame):
 
 class FICSGames(GObject.GObject):
     __gsignals__ = {
-        'FICSGameCreated': (GObject.SignalFlags.RUN_FIRST, None, (object, )),
-        'FICSGameEnded': (GObject.SignalFlags.RUN_FIRST, None, (object, )),
-        'FICSAdjournedGameRemoved': (GObject.SignalFlags.RUN_FIRST, None,
-                                     (object, )),
-        'FICSHistoryGameRemoved': (GObject.SignalFlags.RUN_FIRST, None,
-                                   (object, )),
-        'FICSJournalGameRemoved': (GObject.SignalFlags.RUN_FIRST, None,
-                                   (object, )),
+        "FICSGameCreated": (GObject.SignalFlags.RUN_FIRST, None, (object,)),
+        "FICSGameEnded": (GObject.SignalFlags.RUN_FIRST, None, (object,)),
+        "FICSAdjournedGameRemoved": (GObject.SignalFlags.RUN_FIRST, None, (object,)),
+        "FICSHistoryGameRemoved": (GObject.SignalFlags.RUN_FIRST, None, (object,)),
+        "FICSJournalGameRemoved": (GObject.SignalFlags.RUN_FIRST, None, (object,)),
     }
 
     def __init__(self, connection):
@@ -1126,8 +1215,7 @@ class FICSGames(GObject.GObject):
         self.connection = connection
 
     def start(self):
-        self.connection.adm.connect("onAdjournmentsList",
-                                    self.onAdjournmentsList)
+        self.connection.adm.connect("onAdjournmentsList", self.onAdjournmentsList)
         self.connection.adm.connect("onHistoryList", self.onHistoryList)
         self.connection.adm.connect("onJournalList", self.onJournalList)
         self.connection.bm.connect("curGameEnded", self.onCurGameEnded)
@@ -1141,16 +1229,15 @@ class FICSGames(GObject.GObject):
             raise KeyError
 
     def __setitem__(self, key, value):
-        """ key and value must be the same game """
+        """key and value must be the same game"""
         if not isinstance(key, FICSGame):
             raise TypeError
         if not isinstance(value, FICSGame):
             raise TypeError
         if key != value:
-            raise Exception("Not the same: %s %s" % (repr(key), repr(value)))
+            raise Exception(f"Not the same: {repr(key)} {repr(value)}")
         if hash(value) in self.games:
-            raise Exception("%s already exists in %s" %
-                            (repr(value), repr(self)))
+            raise Exception(f"{repr(value)} already exists in {repr(self)}")
         self.games[hash(value)] = value
         self.games_by_gameno[value.gameno] = value
         if isinstance(value, FICSAdjournedGame):
@@ -1204,7 +1291,12 @@ class FICSGames(GObject.GObject):
         elif create:
             self[game] = game
             if emit:
-                self.emit("FICSGameCreated", [game, ])
+                self.emit(
+                    "FICSGameCreated",
+                    [
+                        game,
+                    ],
+                )
         else:
             raise KeyError
         return game
@@ -1212,16 +1304,17 @@ class FICSGames(GObject.GObject):
     def game_ended(self, game):
         if game in self:
             if not game.move_queue.empty():
-                @asyncio.coroutine
-                def coro(game):
+
+                async def coro(game):
                     # we have to give a chance to ICPlayer
                     # to process the latest move(style12) message
                     # and remove game from game list panel also
-                    yield from asyncio.sleep(0)
+                    await asyncio.sleep(0)
                     game = self[game]
                     self.emit("FICSGameEnded", game)
                     del self[game]
-                create_task(coro(game))
+
+                asyncio.create_task(coro(game))
             else:
                 game = self[game]
                 self.emit("FICSGameEnded", game)
