@@ -1,19 +1,16 @@
 import re
 
 from gi.repository import Gtk
-from pychess.widgets.ChatView import ChatView
-from pychess.widgets.ViewsPanel import ViewsPanel
-from pychess.widgets.InfoPanel import InfoPanel
-from pychess.widgets.ChannelsPanel import ChannelsPanel
 from pychess.System import uistuff
 from pychess.System.prefix import addDataPrefix
 
-TYPE_PERSONAL, TYPE_CHANNEL, TYPE_GUEST, \
-    TYPE_ADMIN, TYPE_COMP, TYPE_BLINDFOLD = range(6)
+TYPE_PERSONAL, TYPE_CHANNEL, TYPE_GUEST, TYPE_ADMIN, TYPE_COMP, TYPE_BLINDFOLD = range(
+    6
+)
 
 
 def get_playername(playername):
-    re_m = re.match("(\w+)\W*", playername)
+    re_m = re.match(r"(\w+)\W*", playername)
     return re_m.groups()[0]
 
 
@@ -24,11 +21,15 @@ __icon__ = addDataPrefix("glade/panel_chat.svg")
 __desc__ = _("List of server channels")
 
 
-class Sidepanel():
-
+class Sidepanel:
     def load(self, widgets, connection, lounge):
         self.connection = connection
 
+        # deferred imports to not slow down PyChess starting up
+        from pychess.widgets.ViewsPanel import ViewsPanel
+        from pychess.widgets.InfoPanel import InfoPanel
+        from pychess.widgets.ChannelsPanel import ChannelsPanel
+
         self.viewspanel = ViewsPanel(self.connection)
         self.channelspanel = ChannelsPanel(self.connection)
         self.adj = self.channelspanel.get_vadjustment()
@@ -45,16 +46,14 @@ class Sidepanel():
         self.chatbox.add2(notebook)
 
         self.panels = [self.viewspanel, self.channelspanel, self.infopanel]
-        self.viewspanel.connect('channel_content_Changed',
-                                self.channelspanel.channel_Highlight, id)
+        self.viewspanel.connect(
+            "channel_content_Changed", self.channelspanel.channel_Highlight, id
+        )
 
-        self.channelspanel.connect('conversationAdded',
-                                   self.onConversationAdded)
-        self.channelspanel.connect('conversationRemoved',
-                                   self.onConversationRemoved)
-        self.channelspanel.connect('conversationSelected',
-                                   self.onConversationSelected)
-        self.channelspanel.connect('focus_in_event', self.focus_in, self.adj)
+        self.channelspanel.connect("conversationAdded", self.onConversationAdded)
+        self.channelspanel.connect("conversationRemoved", self.onConversationRemoved)
+        self.channelspanel.connect("conversationSelected", self.onConversationSelected)
+        self.channelspanel.connect("focus_in_event", self.focus_in, self.adj)
 
         for panel in self.panels:
             panel.show_all()
@@ -66,14 +65,17 @@ class Sidepanel():
         return __widget__
 
     def onConversationAdded(self, panel, grp_id, text, grp_type):
+        # deferred import to not slow down PyChess starting up
+        from pychess.widgets.ChatView import ChatView
+
         chatView = ChatView()
-        plus_channel = '+channel ' + str(grp_id)
+        plus_channel = "+channel " + str(grp_id)
         self.connection.cm.connection.client.run_command(plus_channel)
         for panel in self.panels:
             panel.addItem(grp_id, text, grp_type, chatView)
 
     def onConversationRemoved(self, panel, grp_id):
-        minus_channel = '-channel ' + str(grp_id)
+        minus_channel = "-channel " + str(grp_id)
         self.connection.cm.connection.client.run_command(minus_channel)
         for panel in self.panels:
             panel.removeItem(grp_id)
